@@ -1149,12 +1149,17 @@ class _ExprTree(list):
 
     def top(self):
         """accumulative operation"""
-        return self[1::2]
+        return self[::2]
 
     def bot(self):
         """operation and terminals"""
-        return self[::2]
+        return self[1::2]
 
+    def cut(self, index=2):
+        slice_ = self.searchSubtree(index)
+        new_inds = self[slice_]
+        self.clear()
+        self.extend(new_inds)
 
 class SymbolTree(_ExprTree):
     """ Individual Tree, each tree is one expression"""
